# ChargeModelProductRatePlanChargeRest

Determines how to calculate charges. Charge models must be individually activated in Zuora Billing administration. 

## Enum

* `DISCOUNT_MINUS_FIXED_AMOUNT` (value: `'Discount-Fixed Amount'`)

* `DISCOUNT_MINUS_PERCENTAGE` (value: `'Discount-Percentage'`)

* `FLAT_FEE_PRICING` (value: `'Flat Fee Pricing'`)

* `PER_UNIT_PRICING` (value: `'Per Unit Pricing'`)

* `OVERAGE_PRICING` (value: `'Overage Pricing'`)

* `TIERED_PRICING` (value: `'Tiered Pricing'`)

* `TIERED_WITH_OVERAGE_PRICING` (value: `'Tiered with Overage Pricing'`)

* `VOLUME_PRICING` (value: `'Volume Pricing'`)

* `DELIVERY_PRICING` (value: `'Delivery Pricing'`)

* `MULTIATTRIBUTEPRICING` (value: `'MultiAttributePricing'`)

* `PRERATEDPERUNIT` (value: `'PreratedPerUnit'`)

* `PRERATED_PRICING_BACKTICK` (value: `'PreratedPricing`'`)

* `HIGHWATERMARKVOLUMEPRICING` (value: `'HighWatermarkVolumePricing'`)

* `HIGHWATERMARKTIEREDPRICING` (value: `'HighWatermarkTieredPricing'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


